@@ -16,17 +16,17 @@ if (eval_lutz) {library(lutz)}
 my.geocode <- data.frame(lat = 60.16, lon = 24.93, address = "Helsinki")
 
 ## -----------------------------------------------------------------------------
-sun_angles(time = ymd_hms("2017-06-20 08:00:00", tz = "EET"), geocode = my.geocode)
+sun_angles(time = ymd_hms("2017-06-20 08:00:00", tz = "Europe/Helsinki"), geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
 sun_angles()
 
 ## -----------------------------------------------------------------------------
-sun_angles(time = ymd_hms("2014-01-01 0:0:0", tz = "EET") + hours(c(0, 6, 12)), 
+sun_angles(time = ymd_hms("2014-01-01 0:0:0", tz = "Europe/Helsinki") + hours(c(0, 6, 12)), 
            geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
-my.times <- ymd_hms("2014-01-01 0:0:0", tz = "EET") + hours(c(0, 6, 12))
+my.times <- ymd_hms("2014-01-01 0:0:0", tz = "Europe/Helsinki") + hours(c(0, 6, 12))
 sun_angles(time = my.times, geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
@@ -48,29 +48,29 @@ sun_zenith_angle(time = my.times, geocode = my.geocode)
 sun_azimuth(time = my.times, geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
-dates <- ymd("2015-03-01", tz = "EET") + months(0:5)
+dates <- ymd("2015-03-01", tz = "Europe/Helsinki") + months(0:5)
 dates
 
 ## -----------------------------------------------------------------------------
 sunrise_time(now("UTC"), geocode = my.geocode)
-sunrise_time(now("EET"), geocode = my.geocode)
+sunrise_time(now("Europe/Helsinki"), geocode = my.geocode)
 sunrise_time(now("Europe/Helsinki"), geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
 sunrise_time(geocode = my.geocode)
 sunrise_time(date = now("UTC"), geocode = my.geocode)
 sunrise_time(date = now("UTC"), tz = "UTC", geocode = my.geocode)
-sunrise_time(date = now("EET"), geocode = my.geocode)
-sunrise_time(date = now("EET"), tz = "EET", geocode = my.geocode)
-sunrise_time(today("EET"), tz = "EET", geocode = my.geocode)
+sunrise_time(date = now("Europe/Helsinki"), geocode = my.geocode)
+sunrise_time(date = now("Europe/Helsinki"), tz = "Europe/Helsinki", geocode = my.geocode)
+sunrise_time(today("Europe/Helsinki"), tz = "Europe/Helsinki", geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
 noon_time(now("UTC"), geocode = my.geocode)
-noon_time(now("EET"), geocode = my.geocode)
+noon_time(now("Europe/Helsinki"), geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
 sunset_time(now("UTC"), geocode = my.geocode)
-sunset_time(now("EET"), geocode = my.geocode)
+sunset_time(now("Europe/Helsinki"), geocode = my.geocode)
 
 ## -----------------------------------------------------------------------------
 day_length(dates, geocode = my.geocode)
@@ -85,25 +85,25 @@ sunrise_time(dates, geocode = data.frame(lat = -60, lon = 25))
 noon_time(dates, geocode = data.frame(lat = -60, lon = 25))
 
 ## -----------------------------------------------------------------------------
-sunrise_time(ymd("2017-03-21", tz = "EET"), 
-             tz = "EET", 
+sunrise_time(ymd("2017-03-21", tz = "Europe/Helsinki"), 
+             tz = "Europe/Helsinki", 
              geocode = my.geocode,
              twilight = "civil")
-sunrise_time(ymd("2017-03-21", tz = "EET"), 
-             tz = "EET", 
+sunrise_time(ymd("2017-03-21", tz = "Europe/Helsinki"), 
+             tz = "Europe/Helsinki", 
              geocode = my.geocode,
              twilight = -10)
-sunrise_time(ymd("2017-03-21", tz = "EET"), 
-             tz = "EET", 
+sunrise_time(ymd("2017-03-21", tz = "Europe/Helsinki"), 
+             tz = "Europe/Helsinki", 
              geocode = my.geocode,
              twilight = +12)
 
 ## -----------------------------------------------------------------------------
-sunrise_time(ymd("2017-03-21", tz = "EET"), 
-             tz = "EET", 
+sunrise_time(ymd("2017-03-21", tz = "Europe/Helsinki"), 
+             tz = "Europe/Helsinki", 
              geocode = my.geocode)
-sunrise_time(ymd("2017-03-21", tz = "EET"), 
-             tz = "EET", 
+sunrise_time(ymd("2017-03-21", tz = "Europe/Helsinki"), 
+             tz = "Europe/Helsinki", 
              geocode = my.geocode,
              unit.out = "hours")
 
